@@ -1,6 +1,6 @@
 #   BAREOS - Backup Archiving REcovery Open Sourced
 #
-#   Copyright (C) 2016-2021 Bareos GmbH & Co. KG
+#   Copyright (C) 2016-2023 Bareos GmbH & Co. KG
 #
 #   This program is Free Software; you can redistribute it and/or
 #   modify it under the terms of version three of the GNU Affero General Public
@@ -93,11 +93,18 @@ class DirectorConsole(LowLevel):
             dest="BAREOS_address",
         )
 
+        argparser.add_argument(
+            "--timeout",
+            type=int,
+            help="Timeout (in seconds) for the connection to the Bareos Director.",
+            dest="BAREOS_timeout",
+        )
+
         argparser.add_argument(
             "--protocolversion",
             default=ProtocolVersions.last,
             type=int,
-            help=u"Specify the Bareos console protocol version. Default: {0} (current).".format(
+            help="Specify the Bareos console protocol version. Default: {0} (current).".format(
                 ProtocolVersions.last
             ),
             dest="BAREOS_protocolversion",
@@ -128,6 +135,7 @@ class DirectorConsole(LowLevel):
         self,
         address="localhost",
         port=9101,
+        timeout=None,
         dirname=None,
         name="*UserAgent*",
         password=None,
@@ -145,6 +153,9 @@ class DirectorConsole(LowLevel):
 
            port (int): Port number of the Bareos Director.
 
+           timeout (int, optional):
+              Timeout for the connection to the director. Default: OS dependent
+
            dirname (str, optional):
               Name of the Bareos Director. Deprecated, normally not required.
 
@@ -177,20 +188,23 @@ class DirectorConsole(LowLevel):
         self.pam_password = pam_password
         self.tls_psk_enable = tls_psk_enable
         self.tls_psk_require = tls_psk_require
+        self.timeout = timeout
         if tls_version is not None:
             self.tls_version = tls_version
-        self.identity_prefix = u"R_CONSOLE"
+        self.identity_prefix = "R_CONSOLE"
         if protocolversion is not None:
             self.requested_protocol_version = int(protocolversion)
             self.protocol_messages.set_version(self.requested_protocol_version)
-        self.connect(address, port, dirname, ConnectionType.DIRECTOR, name, password)
+        self.connect(
+            address, port, dirname, ConnectionType.DIRECTOR, name, password, timeout
+        )
         self._init_connection()
         self.max_reconnects = 1
 
     def _finalize_authentication(self):
         code, text = self.receive_and_evaluate_response_message()
 
-        self.logger.debug(u"code: {0}".format(code))
+        self.logger.debug("code: {0}".format(code))
 
         #
         # Test if PAM is requested.
@@ -201,7 +215,7 @@ class DirectorConsole(LowLevel):
         # it will be evaluated with all protocol versions.
         #
         if code == ProtocolMessageIds.PamRequired:
-            self.logger.debug(u"PAM request: {0}".format(text))
+            self.logger.debug("PAM request: {0}".format(text))
             if (not self.pam_username) or (not self.pam_password):
                 raise bareos.exceptions.PamAuthenticationError(
                     "PAM authentication is requested, but no PAM credentials given. Giving up.\n"
@@ -215,7 +229,7 @@ class DirectorConsole(LowLevel):
                 code, text = self.receive_and_evaluate_response_message()
             except bareos.exceptions.ConnectionLostError as e:
                 raise bareos.exceptions.PamAuthenticationError(
-                    u"PAM authentication failed."
+                    "PAM authentication failed."
                 )
         else:
             if (self.pam_username) or (self.pam_password):
@@ -227,7 +241,7 @@ class DirectorConsole(LowLevel):
         # Test if authentication has been accepted.
         #
         if code == ProtocolMessageIds.Ok:
-            self.logger.info(u"Authentication: {0}".format(text))
+            self.logger.info("Authentication: {0}".format(text))
             self.auth_credentials_valid = True
         else:
             raise bareos.exceptions.AuthenticationError(
@@ -242,7 +256,7 @@ class DirectorConsole(LowLevel):
             #
             code, text = self.receive_and_evaluate_response_message()
             if code == ProtocolMessageIds.InfoMessage:
-                self.logger.debug(u"Info: {0}".format(text))
+                self.logger.debug("Info: {0}".format(text))
             else:
                 raise bareos.exceptions.AuthenticationError(
                     "Received unexcepted message: {0} {1} (expecting info message)".format(
